@@ -2,7 +2,6 @@
 Parameter class
 """
 from __future__ import division
-from numpy import arcsin, cos, sin, sqrt, inf, nan, isfinite
 import json
 from copy import deepcopy
 try:
@@ -10,8 +9,8 @@ try:
 except ImportError:
     from ordereddict import OrderedDict
 
+from numpy import array, arcsin, cos, sin, sqrt, inf, nan, isfinite
 from . import uncertainties
-
 from .asteval import Interpreter
 from .astutils import get_ast_names, valid_symbol_name
 
@@ -97,8 +96,8 @@ class Parameters(OrderedDict):
 
         # find the symbols that were added by users, not during construction
         sym_unique = self._asteval.user_defined_symbols()
-        unique_symbols = {key: deepcopy(self._asteval.symtable[key], memo)
-                          for key in sym_unique}
+        unique_symbols = dict((key, deepcopy(self._asteval.symtable[key], memo))
+                              for key in sym_unique)
         _pars._asteval.symtable.update(unique_symbols)
 
         # we're just about to add a lot of Parameter objects to the newly
@@ -152,6 +151,12 @@ class Parameters(OrderedDict):
         self.add_many(*params)
         return self
 
+    def __array__(self):
+        """
+        Parameters to array
+        """
+        return array([float(k) for k in self.values()])
+
     def __reduce__(self):
         """
         Required to pickle a Parameters instance.
@@ -161,8 +166,8 @@ class Parameters(OrderedDict):
 
         # find the symbols from _asteval.symtable, that need to be remembered.
         sym_unique = self._asteval.user_defined_symbols()
-        unique_symbols = {key: deepcopy(self._asteval.symtable[key])
-                          for key in sym_unique}
+        unique_symbols = dict((key, deepcopy(self._asteval.symtable[key]))
+                              for key in sym_unique)
 
         return self.__class__, (), {'unique_symbols': unique_symbols,
                                     'params': params}
@@ -191,14 +196,13 @@ class Parameters(OrderedDict):
         # then add all the parameters
         self.add_many(*state['params'])
 
-
     def update_constraints(self):
         """
         Update all constrained parameters, checking that dependencies are
         evaluated as needed.
         """
-        requires_update = {name for name, par in self.items()
-                           if par._expr is not None}
+        requires_update = set(name for name, par in self.items()
+                              if par._expr is not None)
         updated_tracker = set(requires_update)
 
         def _update_param(name):
@@ -242,11 +246,11 @@ class Parameters(OrderedDict):
         columns : list of strings
             list of columns names to print. All values must be valid
             :class:`Parameter` attributes.
-        precision : int
-            number of digits to be printed after floating point.
-        format : string
+        fmt : string
             single-char numeric formatter. Valid values: 'f' floating point,
             'g' floating point and exponential, 'e' exponential.
+        precision : int
+            number of digits to be printed after floating point.
         """
         if oneline:
             print(self.pretty_repr(oneline=oneline))
@@ -261,7 +265,7 @@ class Parameters(OrderedDict):
                            vary='{vary!s:>{n}}', expr='{expr!s:>{n}}')
         line = ' '.join([otherstyles.get(k, numstyle % k) for k in allcols])
         for name, values in sorted(self.items()):
-            pvalues = {k: getattr(values, k) for k in columns}
+            pvalues = dict((k, getattr(values, k)) for k in columns)
             pvalues['name'] = name
             # stderr is a special case: it is either numeric or None (i.e. str)
             if 'stderr' in columns and pvalues['stderr'] is not None:
@@ -617,6 +621,7 @@ class Parameter(object):
         # becomes stale if parameter.expr is not None.
         if (isinstance(self._val, uncertainties.Variable)
             and self._val is not nan):
+
             try:
                 self.value = self._val.nominal_value
             except AttributeError:
@@ -634,8 +639,10 @@ class Parameter(object):
                     check_ast_errors(self._expr_eval)
 
         v = self._val
-        if v > self.max: v = self.max
-        if v < self.min: v = self.min
+        if v > self.max:
+            v = self.max
+        if v < self.min:
+            v = self.min
         self.value = self._val = v
         return self._val
 
@@ -689,6 +696,10 @@ class Parameter(object):
             check_ast_errors(self._expr_eval)
             self._expr_deps = get_ast_names(self._expr_ast)
 
+    def __array__(self):
+        """array"""
+        return array(float(self._getval()))
+
     def __str__(self):
         """string"""
         return self.__repr__()
